# Generated by Django 3.2.5 on 2021-07-13 05:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0050_auto_20210713_0408'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='characteraudit',
            name='cache_expire_assets',
        ),
        migrations.RemoveField(
            model_name='characteraudit',
            name='cache_expire_clones',
        ),
        migrations.RemoveField(
            model_name='characteraudit',
            name='cache_expire_notif',
        ),
        migrations.RemoveField(
            model_name='characteraudit',
            name='cache_expire_orders',
        ),
        migrations.RemoveField(
            model_name='characteraudit',
            name='cache_expire_pub_data',
        ),
        migrations.RemoveField(
            model_name='characteraudit',
            name='cache_expire_roles',
        ),
        migrations.RemoveField(
            model_name='characteraudit',
            name='cache_expire_skill_que',
        ),
        migrations.RemoveField(
            model_name='characteraudit',
            name='cache_expire_skills',
        ),
        migrations.RemoveField(
            model_name='characteraudit',
            name='cache_expire_wallet',
        ),
        migrations.AddField(
            model_name='characteraudit',
            name='last_update_mails',
            field=models.DateTimeField(blank=True, default=None, null=True),
        ),
    ]
