# Generated by Django 2.2.12 on 2020-07-30 05:20

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0017_auto_20200727_0041'),
    ]

    operations = [
        migrations.AddField(
            model_name='corporationwalletdivision',
            name='name',
            field=models.CharField(default=None, max_length=100, null=True),
        ),
    ]
