# Generated by Django 4.2.13 on 2024-05-27 09:59

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0105_homestationfilter'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='homestationfilter',
            name='constellations',
        ),
        migrations.RemoveField(
            model_name='homestationfilter',
            name='regions',
        ),
        migrations.RemoveField(
            model_name='homestationfilter',
            name='systems',
        ),
    ]
