# Generated by Django 4.2.5 on 2023-09-20 10:51

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0092_poco'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='characteraudit',
            options={'permissions': (('corp_hr', "Can access other character's data for own corp."), ('alliance_hr', "Can access other character's data for own alliance."), (
                'state_hr', "Can access other character's data for own state."), ('guest_hr', "Can access guest users's data for HR purposes."), ('global_hr', "Can access other character's data for characters in any corp/alliance/state."))},
        ),
    ]
