@keyframes _spin_o9fr8_1{0%{transform:rotate(0)}to{transform:rotate(359deg)}}._refreshAnimate_o9fr8_10{-animation:_spin_o9fr8_1 2s infinite linear;-ms-animation:_spin_o9fr8_1 2s infinite linear;-webkit-animation:_spin_o9fr8_1 2s infinite linear;-moz-animation:_spin_o9fr8_1 2s infinite linear}._filterBtn_o9fr8_17{color:gray!important;margin-top:2px!important;min-height:38px!important;background-color:#fff!important;border-color:#ccc!important;border-top-left-radius:4px!important;border-bottom-left-radius:4px!important;border-right:0!important;border-width:1px!important;font-weight:700!important;display:flex!important;font-size:15px!important;font-family:Lato,Helvetica Neue,Helvetica,Arial,sans-serif!important}._filterToggle_o9fr8_33{stroke:#ccc!important;fill:#ccc!important;stroke-width:0;padding-top:8px!important;margin-top:2px!important;min-height:38px!important;background-color:#fff!important;border-color:#ccc!important;border-top-right-radius:4px!important;border-bottom-right-radius:4px!important;border-left:0!important;border-width:1px!important;display:flex!important;font-size:15px!important}._box_203nf_23{background-color:var(--bs-body-bg);width:100%}._searchInput_203nf_28{background-color:var(--bs-body-bg);color:var(--bs-body-color);border:var(--bs-border-width) solid var(--bs-border-color);width:100%;transition:width 1s;outline:none;border-radius:var(--bs-border-radius);padding:.375em;font-size:var(--bs-body-font-size)}._radioWrapper_203nf_40{width:100px}@media (prefers-reduced-motion: reduce){._input_203nf_45{transition:none}}._searchInput_203nf_28::placeholder{color:var(--bs-secondary-text-emphasis)}._searchInput_203nf_28:focus-visible,._searchButton_203nf_55:focus-visible{box-shadow:0 0 0 .25rem var(--bs-primary-border-subtle)}._searchWrapper_203nf_64,._searchWrapperFrom_203nf_68{position:relative}._searchIcon_203nf_72,._xIcon_203nf_73{position:absolute;width:1rem;height:1rem;right:.25rem;top:50%;translate:0 -50%;color:var(--bs-secondary-text-emphasis);opacity:0;rotate:90deg;pointer-events:none;visibility:hidden;border-radius:.25rem;transition-behavior:discrete;transition-property:opacity,rotate,visibility;transition-duration:.5s}._searchWrapper_203nf_64:has(._searchInput_203nf_28:placeholder-shown) ._searchIcon_203nf_72,._searchWrapper_203nf_64:has(._searchInput_203nf_28:not(:placeholder-shown)) ._xIcon_203nf_73{opacity:1;pointer-events:all;rotate:0deg;visibility:visible}._searchWrapperFrom_203nf_68[aria-describedby=popover-positioned-top]>div>._dropDownIcon_203nf_99{rotate:180deg!important}._searchWrapper_203nf_64:has(button) button{all:unset;cursor:pointer;position:absolute;width:1rem;height:1rem;right:.25rem;top:50%;translate:0 -50%}._searchInput_203nf_28[type=search]::-ms-clear,._searchInput_203nf_28[type=search]::-ms-reveal{-webkit-appearance:none;-moz-appearance:none;appearance:none;width:0;height:0}._searchInput_203nf_28[type=search]::-webkit-search-decoration,._searchInput_203nf_28[type=search]::-webkit-search-cancel-button,._searchInput_203nf_28[type=search]::-webkit-search-results-button,._searchInput_203nf_28[type=search]::-webkit-search-results-decoration{-webkit-appearance:none;-moz-appearance:none;appearance:none}._flexContainer_ia7nm_1{display:flex;align-items:center;justify-content:center;align-content:center;flex-wrap:wrap;flex-direction:row}@keyframes _shake_ia7nm_1{10%,90%{transform:translate3d(-1px,0,0)}20%,80%{transform:translate3d(2px,0,0)}30%,50%,70%{transform:translate3d(-4px,0,0)}40%,60%{transform:translate3d(4px,0,0)}}._errorAnim_ia7nm_33{animation:_shake_ia7nm_1 .82s cubic-bezier(.36,.07,.19,.97) both;animation-iteration-count:infinite}._ldsDualRing_ia7nm_38{display:inline-block;width:80px;height:80px;margin:15px}._ldsDualRing_ia7nm_38:after{content:"";display:block;width:100%;height:100%;border-radius:50%;border:6px solid currentColor;border-color:currentColor transparent currentColor transparent;animation:_lds-dual-ring_ia7nm_1 1.2s linear infinite}@keyframes _lds-dual-ring_ia7nm_1{0%{transform:rotate(0)}to{transform:rotate(360deg)}}._strikeOut_1bswx_1{display:flex;flex-direction:row;margin:0}._strikeOut_1bswx_1:before,._strikeOut_1bswx_1:after{content:"";flex:1 1;border-bottom:1px solid var(--bs-border-color);margin:auto}._strikeOut_1bswx_1:before,._strikeOut_1bswx_1:after{margin-right:10px;margin-left:10px}._skillBlock_1v52a_1{width:100%}@media (min-width: 1000px){._skillBlock_1v52a_1{width:50%}}@media (min-width: 1400px){._skillBlock_1v52a_1{width:33%}}._menuRefreshSpin_17lcv_1{-animation:_spin_17lcv_1 2s infinite linear;-ms-animation:_spin_17lcv_1 2s infinite linear;-webkit-animation:_spin_17lcv_1 2s infinite linear;-moz-animation:_spin_17lcv_1 2s infinite linear}@keyframes _spin_17lcv_1{0%{transform:rotate(0)}to{transform:rotate(359deg)}}
