# Generated by Django 4.2.8 on 2024-01-07 11:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0099_remove_rolefilter_alliance_filter_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='mapjumpbridge',
            name='manually_input',
            field=models.BooleanField(default=False),
        ),
    ]
