# Generated by Django 4.0.10 on 2023-11-25 09:17

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('eveonline', '0017_alliance_and_corp_names_are_not_unique'),
        ('corptools', '0096_rolefilter_main_only'),
    ]

    operations = [
        migrations.AddField(
            model_name='rolefilter',
            name='alliances_filter',
            field=models.ManyToManyField(
                blank=True, related_name='audit_role_filters', to='eveonline.eveallianceinfo'),
        ),
        migrations.AddField(
            model_name='rolefilter',
            name='corps_filter',
            field=models.ManyToManyField(
                blank=True, related_name='audit_role_filters', to='eveonline.evecorporationinfo'),
        ),
    ]
