# Generated by Django 3.2.8 on 2022-01-09 11:44

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0066_final_notification_checks'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='notification',
            name='notification_text',
        ),
    ]
